---
title: 가상계좌는 어떻게 테스트 할 수 있나요?
category: 자주 묻는 질문 (일반 문의) > 결제서비스 > 결제서비스
seo:
  title: 가상계좌 테스트 결제방법
  description: 가상계좌 테스트 방법 및 가상계좌 테스트 강제환불 방법까지 중요한 체크사항에 대해 포트원이 안내드립니다.
  keywords:
    - 일반결제
tags:
  - 공통
  - 일반결제
  - 가상계좌
pgCompanies:
  - 공통
searchTags:
  - KC이니시스 가상계좌 테스트
  - 가상계좌 테스트 환불
  - 가상계좌
  - 가상계좌 테스트
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="가상계좌의 테스트 결제방법을 안내해 드립니다. 테스트 환경에서는 발급된 가상 계좌에 실제 입금하시면 환불이 불가하오니 실 입금은 지양해 주시기 바랍니다." />

### **가상계좌 테스트 방법**

결제대행사에서는 테스트 환경의 가상 계좌 환불 기능을 제공하고 있지 않습니다. 하지만, 입금이 되었음을 알리는 통지를 통해 임의로 결제 완료 응답을 받아보실 수가 있습니다.

임의로 통지를 받아 결제상태가 ‘결제 완료' 로 변경된 경우 실 입금이 되지 않았기 때문에 취소 테스트가 불가하며 API 호출 시  '요청하신 건에 대해 입금된 내역이 없습니다' 등의 오류메시지가 응답되니 참고해주시기 바랍니다.

- 웹훅 임의 통지 경로 : [포트원 관리자콘솔↗](https://admin.portone.io/) > 테스트 결제내역 클릭 > 결제내역 상세 > 테스트 입금웹훅통지 클릭



### **체크사항**

1. **포트원 내 웹훅 설정 여부 확인하기**



**2. 테스트된 결제내역을 확인하기 위해 필터링 옵션 '테스트결제' 체크하기**



**3. 실 운영환경의 경우 가상계좌 환불** 특약 **여부 체크하기**

실 운영환경에서도 가상계좌 환불 서비스를 이용하시려면 PG 사를 통해 환불 특약을 맺어야 합니다.  (다날 PG사 예외 : 가상계좌 환불 미지원)

#### **가상계좌 실 입금 거래 강제환불 방법**

가상계좌는 실 입금에 대한 통지나 결제상태 동기화가 어려우며, 마찬가지로 환불도 불가합니다.

만약 실수로 테스트 환경에서 발급받으신 계좌로 실 입금을 하셨다면 강제 환불 처리가 필요합니다. 포트원 고객센터로 거래 건의 정보를 아래의 형식으로 작성하여 전달해주시기 바랍니다. (<cs@portone.io>)

- 가입 PG사명 :
- 거래 고유번호(imp\_uid) :
- 결제 금액 :
- 환불 계좌 정보 : 은행 / 계좌번호 / 예금주명

#### **KG이니시스 가상계좌로 실 입금을 하신 경우**

KG이니시스의 경우 아래의 경로로 직접 강제환불 처리가 가능합니다.

- 경로 : [KG이니시스 상점관리자페이지↗](https://iniweb.inicis.com/security/login.do) 로그인 (ID : INIpayTest / PW : inicis\~1111) > 거래내역 > 가상계좌 ‘입금결과조회’ > 주문번호 항목에 포트원 imp\_uid 입력 후 조회

